@@ -15,7 +15,9 @@ import aws_cdk.core._jsii
 import aws_cdk.custom_resources._jsii
 import constructs._jsii
 
-__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-cognito", "1.47.1", __name__[0:-6], "aws-cognito@1.47.1.jsii.tgz")
+__jsii_assembly__ = jsii.JSIIAssembly.load(
+    "@aws-cdk/aws-cognito", "1.50.0", __name__[0:-6], "aws-cognito@1.50.0.jsii.tgz"
+)
 
 __all__ = [
     "__jsii_assembly__",
